===============
Testing Project
===============


.. image:: https://img.shields.io/pypi/v/testing_project.svg
        :target: https://pypi.python.org/pypi/testing_project

.. image:: https://img.shields.io/travis/ellesmith88/testing_project.svg
        :target: https://travis-ci.com/ellesmith88/testing_project

.. image:: https://readthedocs.org/projects/testing-project/badge/?version=latest
        :target: https://testing-project.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Project to show cookiecutter and release procedure


* Free software: BSD - see LICENSE file in top-level package directory
* Documentation: https://testing-project.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
